"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const proxy_1 = require("./proxy");
const bson_1 = require("bson");
const ndjson = process.argv[2] === '--ndjson';
if (ndjson)
    process.argv.splice(2, 1);
const targetStr = process.argv[2];
const localStr = process.argv[3];
if (!targetStr || !localStr) {
    console.log('usage: mongodb-wp-proxy [--ndjson] <remotehost:remoteport> <[localhost:]localport>');
    return;
}
let target;
if (targetStr.startsWith('/') || targetStr.includes('\\')) {
    target = { path: targetStr };
}
else {
    const [host, port] = targetStr.split(':');
    target = { host, port: +port };
}
let local;
if (localStr.startsWith('/') || localStr.includes('\\')) {
    local = { path: localStr };
}
else {
    const [host, port] = localStr.split(':');
    if (port === undefined) {
        local = { port: +host };
    }
    else {
        local = { host, port: +port };
    }
}
(async () => {
    const proxy = new proxy_1.Proxy(target);
    proxy.on('newConnection', (conn) => {
        if (ndjson) {
            console.log(JSON.stringify({ ev: 'newConnection', conn }));
        }
        else {
            console.log(`[${conn.id} outgoing] New connection from ${conn.incoming}`);
        }
        conn.on('connectionEnded', (source) => {
            if (ndjson) {
                console.log(JSON.stringify({ ev: 'connectionEnded', conn, source }));
            }
            else {
                console.log(`[${conn.id} ${source}] Connection closed`);
            }
        });
        conn.on('connectionError', (source, err) => {
            if (ndjson) {
                console.log(JSON.stringify({ ev: 'connectionError', conn, source, err: err.message }));
            }
            else {
                console.log(`[${conn.id} ${source}] Connection error: ${err.message}`);
            }
        });
        conn.on('message', (source, msg) => {
            if (ndjson) {
                console.log(bson_1.EJSON.stringify({ ev: 'message', conn: conn.toJSON(), source, msg }));
            }
            else {
                console.log(`[${conn.id} ${source}] Message received`);
                console.dir(msg.contents, { depth: Infinity, customInspect: true });
            }
        });
        conn.on('parseError', (source, err) => {
            if (ndjson) {
                console.log(JSON.stringify({ ev: 'parseError', conn, source, err: err.message }));
            }
            else {
                console.log(`[${conn.id} ${source}] Failed to parse message: ${err.message}`);
            }
        });
    });
    await proxy.listen(local);
    if (ndjson) {
        console.log(JSON.stringify({ ev: 'listening', addr: proxy.address(), local, target }));
    }
    else {
        console.log('Listening on', proxy.address(), 'forwarding', local, 'to', target);
    }
})().catch((err) => process.nextTick(() => { throw err; }));
//# sourceMappingURL=cli.js.map